@@ -66,6 +66,8 @@ as_bundle_kind_to_string (AsBundleKind kind)
 		return "appimage";
 	if (kind == AS_BUNDLE_KIND_SNAP)
 		return "snap";
+    if (kind == AS_BUNDLE_KIND_TARBALL)
+		return "tarball";
 	return "unknown";
 }
 
@@ -90,6 +92,8 @@ as_bundle_kind_from_string (const gchar *bundle_str)
 		return AS_BUNDLE_KIND_APPIMAGE;
 	if (g_strcmp0 (bundle_str, "snap") == 0)
 		return AS_BUNDLE_KIND_SNAP;
+    if (g_strcmp0 (bundle_str, "tarball") == 0)
+		return AS_BUNDLE_KIND_TARBALL;
 	return AS_BUNDLE_KIND_UNKNOWN;
 }
 
